import sys
import purchases
import interstitials
import levels
import rewarded_video
import spent_gems


def analytics(command, arg_parser):
    command
    files = sys.argv[2:]
    if command == 'an_purchases':
        purchases.main(files)
    elif command == 'an_interstitial':
        interstitials.main(files)
    elif command == 'an_levels':
        levels.main(files)
    elif command == 'an_video':
        rewarded_video.main(files)
    elif command == 'an_gems':
        spent_gems.main(files)



import parse_csv
import diagram


def interstials(file):
    table = parse_csv.parse(file)
    table.save('AdsInterstitial_raw.txt')
    caption = 'Ads interstitial\n' + file

    count_yes = table.count_if('ad_availabled', '"{}"=="yes"')
    count_no = table.count_if('ad_availabled', '"{}"=="no"')
    count_no_inet = table.count_if('internet', '"{}"=="no"')
    count_no_inet = min(count_no_inet, count_no)
    fillrate = round(100.0 * count_yes / (count_yes + count_no - count_no_inet), 1)
    fillrate2 = round(100.0 * count_yes / (count_yes + count_no), 1)

    count_normal = table.count_if('level_mode', '"{}"=="normal"')
    count_survival = table.count_if('level_mode', '"{}"=="survival"')
    normal = round(100.0 * count_normal / (count_normal + count_survival), 1)
    survival = round(100.0 * count_survival / (count_normal + count_survival), 1)

    count = table.max('level_index')
    values = []
    print 'Level:\tImpressions'
    for level in xrange(count + 1):
        value = table.count_if('level_index', '{}==%s' % level)
        print '{}\t{}'.format(level, value)
        values.append(value)
    values[0] -= count_survival
    diagram.build(values, caption, 'ads_interstitial.png', add_text='''
        Fillrate with internet: {}%
        Fillrate total: {}%
        Impresions on levels: {}%
        Impresions on survival: {}%
        '''.format(fillrate, fillrate2, normal, survival))


def main(argv):
    file = 'AdsInterstitial.csv'
    if len(argv) > 0:
        file = argv[0]
    interstials(file)

if __name__ == '__main__':
    main([])



import xml.etree.ElementTree as ET
import os
import fileutils

logs = []


def validate():
    root = ET.parse(fileutils.root_dir + '/Resources/ini/sounds.xml').getroot()
    for sound in root:
        file = sound.attrib['value']
        file = file.replace('##music_dir##', '/Resources/audio/music/')
        file = file.replace('##sound_dir##', '/Resources/audio/sound/')
        file = file.replace('##music_ext##', '.mp3')
        file = file.replace('##sound_ext##', '.mp3')
        file = fileutils.root_dir + file
        abspath = os.path.abspath(file)
        abspath = abspath.replace('\\', '/')
        file = file.replace('\\', '/')
        if not os.path.isfile(file) or file != abspath:
            logs.append('Not founded: ' + file + ' name: ' + sound.attrib['name'])



from PIL import Image


def launch_images(infile, sizes=None, filename_format='{}x{}.png'):
    if sizes is None:
        sizes = [
            (640, 960),
            (640, 1136),
            (1024, 768),
            (2048, 1536),
            (2208, 1242),
        ]

    for size in sizes:
        outfile = filename_format.format(size[0], size[1])
        im = Image.open(infile)
        if size[0] < size[1]:
            s = max(im.width, im.height)
            im = im.resize((s, s), 1)
            im = im.rotate(-90)
            im = im.resize((size[0], size[1]), 1)
            im.save(outfile, "PNG")

        rx = 1.0 * size[0] / im.width
        ry = 1.0 * size[1] / im.height

        if rx != ry:
            r = max(rx, ry)
            rsize = (int(im.width * r), int(im.height * r))
            im = im.resize(rsize, 1)
            l = (rsize[0] - size[0]) / 2
            r = im.width - l
            t = (rsize[1] - size[1]) / 2
            b = im.height - t
            im = im.crop((l, t, r, b))
        else:
            im = im.resize(size, 1)
        im = im.resize(size, 1)
        im.save(outfile, "PNG")


def icons(infile, sizes=None, filename_format='Icon-{}.png'):
    if sizes is None:
        sizes = [20, 29, 32, 40, 48, 58, 60, 72, 76, 80, 87, 96, 120, 152, 167, 180, 512, 1024]
    for size in sizes:
        outfile = filename_format.format(size)
        im = Image.open(infile)
        im.thumbnail((size, size), Image.ANTIALIAS)
        im.save(outfile, "PNG")


if __name__ == '__main__':
    launch_images('1920x1080.png')



import parse_csv
import diagram


def collect(deck, upgrader):
    table_deck = parse_csv.parse(deck)
    table_upgrader = parse_csv.parse(upgrader)
    table_deck.save('AdsVideoResult_deck_raw.txt')
    table_upgrader.save('AdsVideoResult_upgrader_raw.txt')
    caption_deck = 'Ads Video Result (Deck Selector + Cards Upgrader)\n' + deck + '\n' + upgrader

    count_yes = table_deck.count_if('result_reward', '"{}"=="yes"')
    count_no = table_deck.count_if('result_reward', '"{}"=="no"')
    count_no_inet = table_deck.count_if('internet', '"{}"=="no"')
    count_no_inet = min(count_no_inet, count_no)
    fillrate = round(100.0 * count_yes / (count_yes + count_no - count_no_inet), 1)
    fillrate2 = round(100.0 * count_yes / (count_yes + count_no), 1)

    total = len(table_deck.rows) + len(table_upgrader.rows)
    play_deck = round(100.0 * len(table_deck.rows) / total, 1)
    play_upgr = round(100.0 * len(table_upgrader.rows) / total, 1)

    count = max(table_deck.max('player_progress'), table_upgrader.max('player_level'))
    values = []
    values2 = []
    print 'Level:\tImpressions'
    for level in xrange(count + 1):
        value = table_deck.count_if('player_progress', '{}==%s' % level)
        value2 = table_upgrader.count_if('player_level', '{}==%s' % level)
        values.append(value)
        values2.append(value2)
    diagram.build(values, caption_deck, 'ads_rewarded_video.png',
                  values2=values2,
                  add_to_index=0,
                  add_text='''
        Fillrate with internet: {}%
        Fillrate total: {}%
        Impressions on deck selector: {}%
        Impressions on cards upgrader: {}%
        Total impresions count: {}
        '''.format(fillrate, fillrate2, play_deck, play_upgr, count_yes + len(table_upgrader.rows)))


def main(argv):
    deck = 'AdsVideoResult.csv'
    upgrader = 'ShowVideoCardsUpgrader.csv'
    if len(argv) > 1:
        deck = argv[0]
        upgrader = argv[1]
    collect(deck, upgrader)

if __name__ == '__main__':
    main([])



import json
import fileutils
import os


class Services:

    def __init__(self):
        self.appodeal_id = ''
        self.flurry_id = ''
        self.facebook_id = ''
        self.gsm_sender_id = ''


class Project(object):

    instance = None

    def __init__(self, arg_parser, empty=False):
        super(Project, self).__init__()
        self.with_pro_version = False
        self.services = None
        self.arg_parser = arg_parser
        if not empty:
            self._parse()

    def create(self):
        data = {}
        data['name'] = ''
        data['app_package'] = ''
        data['app_name'] = ''
        data['app_bundle_name'] = ''
        data['app_version'] = ''
        data['google_spreedsheet_inapps_id'] = ''
        data['google_api_secret_path'] = ''
        data['apple_auth_user'] = ''
        data['apple_auth_password'] = ''
        data['apple_id'] = ''
        data['apple_inapps_token'] = ''
        data['apple_team_id'] = ''

        # services
        data['services'] = {}
        data['services']['ios'] = {}
        data['services']['android'] = {}
        data['services']['ios']['flurry_id'] = ''
        data['services']['ios']['appodeal_id'] = ''
        data['services']['ios']['facebook_id'] = ''
        data['services']['ios']['gsm_sender_id'] = ''
        data['services']['android']['flurry_id'] = ''
        data['services']['android']['appodeal_id'] = ''
        data['services']['android']['facebook_id'] = ''
        data['services']['android']['gsm_sender_id'] = ''

        path = fileutils.root_dir + '/project.json'
        open(path, 'w').write(json.dumps(data, sort_keys=True, indent=4))
        fileutils.createDir(fileutils.root_dir + '/store')
        fileutils.createDir(fileutils.root_dir + '/store/inapps.itmsp')
        fileutils.write(fileutils.root_dir + '/store/inapps.itmsp/machine-local-data.xml', '<root/>')
        fileutils.write(fileutils.root_dir + '/store/inapps.itmsp/metadata.xml', '<root/>')
        fileutils.write(fileutils.root_dir + '/store/android_inapps.csv',
                        'Product ID,Published State,Purchase Type,Auto Translate,Locale; Title; Description,Auto Fill Prices,Price,Pricing Template ID')

    def _parse(self):
        path = fileutils.root_dir + '/project.json'
        if not os.path.isfile(path):
            print 'Cannot find project file [project.json]'
            exit(-1)
        data_file = open(path)
        data = json.load(data_file)
        self.project_name = data['name'] if 'name' in data else None
        self.package = data['app_package']
        self.version = data['app_version']
        self.gg_secret_file = fileutils.root_dir + '/' + data['google_api_secret_path']
        self.apple_auth_user = data['apple_auth_user']
        self.apple_auth_password = data['apple_auth_password']
        self.apple_team_id = data['apple_team_id']
        self.validate = data['validator_properties'] if 'validator_properties' in data else {}
        if self.project_name is None:
            k = self.package.rfind('.')
            self.project_name = self.package[k + 1:]

        def read_services(platform, kind):
            if 'lite' in data and 'pro' in data:
                js = data[kind]['services'][platform]
                self.with_pro_version = True
                self.services[platform][kind] = Services()
                self.services[platform][kind].flurry_id = js['flurry_id']
                self.services[platform][kind].appodeal_id = js['appodeal_id']
                self.services[platform][kind].facebook_id = js['facebook_id']
                self.services[platform][kind].gsm_sender_id = js['gsm_sender_id']
            else:
                js = data['services'][platform]
                self.with_pro_version = False
                self.services[platform] = Services()
                self.services[platform].flurry_id = js['flurry_id']
                self.services[platform].appodeal_id = js['appodeal_id']
                self.services[platform].facebook_id = js['facebook_id']
                self.services[platform].gsm_sender_id = js['gsm_sender_id']

        def read_variable(kind, parameter):
            if kind in data and parameter in data[kind]:
                return data[kind][parameter]
            return data[parameter] if parameter in data else ''

        self.services = {}
        self.services['ios'] = {}
        self.services['android'] = {}
        read_services('ios', 'lite')
        read_services('ios', 'pro')
        read_services('android', 'lite')
        read_services('android', 'pro')

        self.name = read_variable(self.arg_parser.app_kind, 'app_name')
        self.app_bundle_name = read_variable(self.arg_parser.app_kind, 'app_bundle_name')
        self.apple_id = read_variable(self.arg_parser.app_kind, 'apple_id')
        self.apple_inapps_token = read_variable(self.arg_parser.app_kind, 'apple_inapps_token')
        self.gg_inapps = read_variable(self.arg_parser.app_kind, 'google_spreedsheet_inapps_id')
        self.gg_locales = read_variable(self.arg_parser.app_kind, 'google_spreedsheet_localisation_id')

        if self.with_pro_version and self.arg_parser.app_kind != 'lite':
            self.package += '.' + self.arg_parser.app_kind



import os
from os.path import isfile, isdir
import xml.etree.ElementTree as ET
import xml.dom.minidom
import hashlib


root_dir = ''
ignore_folders = []
resources = []
xmls = []
images = []
atlases = []
fonts = []
spriteframes = {}
atlas_names = {}
unused = []


def createDir(path):
    if not os.path.exists(path):
        print 'Create directory [{}]'.format(path)
        os.makedirs(path)


def createDirForFile(file):
    dir = file
    if '/' not in dir:
        return
    k = dir.rindex('/')
    dir = dir[:k]
    createDir(dir)


def _getFilesList(path, prefix='', recursive=True):
    try:
        list = os.listdir(path)
        listFiles = []
        for i in list:
            if recursive and isdir(path + i):
                result = _getFilesList(path + i + "/", prefix + i + "/")
                for r in result:
                    listFiles.append(r)
            if isfile(path + i):
                listFiles.append(prefix + i)
        return listFiles
    except OSError as e:
        print '============================'
        print "Except: I/O error({0}): {1}".format(e.errno, e.strerror)
        print 'FileUtils::_getFilesList({}, {})'.format(path, prefix)
        print '============================'
        return []


def getFoldersList(path):
    try:
        list = os.listdir(path)
        foldersFiles = []
        for i in list:
            if isdir(path + i) and i[0] != '.':
                foldersFiles.append(i)
        return foldersFiles
    except OSError as e:
        print '============================'
        print "Except: I/O error({0}): {1}".format(e.errno, e.strerror)
        print 'FileUtils::getFoldersList({})'.format(path)
        print '============================'
        return []


def getFilesList(path, recursive=True):
    if not path.endswith('/'):
        path += '/'
    return _getFilesList(path, "", recursive)


def write(file, data):
    createDirForFile(file)
    exist = isfile(file)
    log_title = 'update' if exist else 'create'
    if not exist or open(file).read() != data:
        print log_title, file
        open(file, 'w').write(data)


def getSize(file):
    return os.path.getsize(file)


def save_xml(file, root):
    buffer = ET.tostring(root)
    xml_ = xml.dom.minidom.parseString(buffer)
    buffer = xml_.toprettyxml(encoding='utf-8')
    lines = buffer.split('\n')
    buffer = ''
    for line in lines:
        if line.strip():
            buffer += line + '\n'
    write(file, buffer)


def inspectResources():
    root = root_dir + '/Resources/'
    global resources
    resources = getFilesList(root)
    for file in resources:
        ignore = False
        for folder in ignore_folders:
            ignore = ignore or file.startswith(folder + '/')
        if ignore:
            resources.remove(file)
            continue
        if file.endswith('.xml'):
            xmls.append(file)
        elif file.endswith('.plist'):
            atlases.append(file)
        elif file.endswith('.png') or file.endswith('.jpg'):
            images.append(file)
        elif file.endswith('.ttf') or file.endswith('.fnt'):
            fonts.append(file)
    parse_atlases()


def parse_atlases():
    def critical_error(msg):
        print msg
        print '\n All atlases:\n\n', '\n'.join(atlases)
        exit(-1)

    def parse_atlas_name():
        # from code:
        atlas_names['images/other.plist'] = 'other'
        if 'ini/title/layer.xml' in xmls:
            xmlroot = ET.parse(root_dir + '/Resources/ini/title/layer.xml').getroot()
            xml_ress = xmlroot.find('resources').find('atlases')
            for xml_res in xml_ress:
                path = xml_res.attrib['path']
                name = xml_res.attrib['name']
                if path not in atlases:
                    critical_error('Critical Error: atlas {} not found \n'.format(path))
                atlas_names[path] = name
        else:
            print 'Warning: cannot find file with mainpack resources'
        if 'ini/gamescene/resources.xml' in xmls:
            xmlroot = ET.parse(root_dir + '/Resources/ini/gamescene/resources.xml').getroot()
            xml_ress = xmlroot.find('resources')
            for child in xml_ress:
                if child.tag != 'resoucre':
                    continue
                for xml_res in child:
                    path = xml_res.attrib['path']
                    name = xml_res.attrib['name']
                    if path not in atlases:
                        critical_error('Critical Error: atlas {} not found \n'.format(path))
                        exit(-1)
                    atlas_names[path] = name
        else:
            print 'Warning: cannot find file with mainpack resources'

    parse_atlas_name()
    for file in atlases:
        if file not in atlas_names:
            unused.append(file)
            continue
        atlas_name = atlas_names[file]
        if atlas_name not in spriteframes:
            spriteframes[atlas_name] = []
        xmlroot = ET.parse(root_dir + '/Resources/' + file).getroot()
        dict_ = xmlroot.find('dict')
        br = False
        for child in dict_:
            if child.tag == 'dict' and br:
                for framexml in child:
                    if framexml.tag == 'key':
                        frame = framexml.text
                        spriteframes[atlas_name].append(frame)
                break
            if child.tag == 'key' and child.text == 'frames':
                br = True


def getMd5File(file):
    m = hashlib.md5()
    m.update(open(file, 'rb').read())
    return str(m.hexdigest())
